@@ -52,6 +52,7 @@ typedef struct _RemminaMain {
 	GtkMenu *		menu_popup;
 	GtkMenuButton *		menu_header_button;
 	GtkMenu *		menu_popup_full;
+	GtkMenu *       menu_popup_delete_rc;
 	GtkRadioMenuItem *	menuitem_view_mode_list;
 	GtkRadioMenuItem *	menuitem_view_mode_tree;
 	GtkMenuItem *		menuitem_connection_quit;
@@ -123,6 +124,7 @@ void remmina_main_on_action_application_quit(GSimpleAction *action, GVariant *pa
 void remmina_main_on_action_connection_connect(GSimpleAction *action, GVariant *param, gpointer data);
 void remmina_main_on_action_connection_copy(GSimpleAction *action, GVariant *param, gpointer data);
 void remmina_main_on_action_connection_delete(GSimpleAction *action, GVariant *param, gpointer data);
+void remmina_main_on_action_connection_delete_multiple(GSimpleAction *action, GVariant *param, gpointer data);
 void remmina_main_on_action_connection_edit(GSimpleAction *action, GVariant *param, gpointer data);
 void remmina_main_on_action_connection_external_tools(GSimpleAction *action, GVariant *param, gpointer data);
 void remmina_main_on_action_connection_new(GSimpleAction *action, GVariant *param, gpointer data);
@@ -136,5 +138,6 @@ void remmina_main_on_action_tools_import(GSimpleAction *action, GVariant *param,
 void remmina_main_on_action_expand(GSimpleAction *action, GVariant *param, gpointer data);
 void remmina_main_on_action_collapse(GSimpleAction *action, GVariant *param, gpointer data);
 void remmina_main_on_action_search_toggle(GSimpleAction *action, GVariant *param, gpointer data);
+void remmina_main_reload_preferences();
 
 G_END_DECLS
