@@ -55,7 +55,7 @@
 #include "remmina_log.h"
 #include "remmina/remmina_trace_calls.h"
 
-const gchar *default_resolutions = "640x480,800x600,1024x768,1152x864,1280x960,1400x1050";
+const gchar *default_resolutions = "640x480,800x600,1024x768,1152x864,1280x960,1400x1050,1920x1080";
 const gchar *default_keystrokes = "Send hello world§hello world\\n";
 
 gchar *remmina_keymap_file;
@@ -319,6 +319,12 @@ void remmina_pref_init(void)
 	else
 		remmina_pref.lock_edit = FALSE;
 
+
+	if (g_key_file_has_key(gkeyfile, "remmina_pref", "lock_view_passwords", NULL))
+		remmina_pref.lock_view_passwords = g_key_file_get_boolean(gkeyfile, "remmina_pref", "lock_view_passwords", NULL);
+	else
+		remmina_pref.lock_view_passwords = FALSE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "enc_mode", NULL))
 		remmina_pref.enc_mode = g_key_file_get_integer(gkeyfile, "remmina_pref", "enc_mode", NULL);
 	else
@@ -792,7 +798,7 @@ gboolean remmina_pref_save(void)
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "deny_screenshot_clipboard", remmina_pref.deny_screenshot_clipboard);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "save_view_mode", remmina_pref.save_view_mode);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "confirm_close", remmina_pref.confirm_close);
-	if (g_key_file_remove_key (gkeyfile, "remmina_pref", "use_master_password", NULL))
+	if (g_key_file_remove_key(gkeyfile, "remmina_pref", "use_master_password", NULL))
 		REMMINA_DEBUG("use_master_password removed…");
 	else
 		REMMINA_INFO("use_master_password already migrated");
@@ -802,12 +808,14 @@ gboolean remmina_pref_save(void)
 	g_key_file_set_string(gkeyfile, "remmina_pref", "unlock_password", remmina_pref.unlock_password);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "lock_connect", remmina_pref.lock_connect);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "lock_edit", remmina_pref.lock_edit);
+	g_key_file_set_boolean(gkeyfile, "remmina_pref", "lock_view_passwords", remmina_pref.lock_view_passwords);
 #else
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "use_primary_password", FALSE);
 	g_key_file_set_integer(gkeyfile, "remmina_pref", "unlock_timeout", 0);
 	g_key_file_set_string(gkeyfile, "remmina_pref", "unlock_password", g_strdup(""));
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "lock_connect", FALSE);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "lock_edit", FALSE);
+	g_key_file_set_boolean(gkeyfile, "remmina_pref", "lock_view_passwords", FALSE);
 #endif
 	g_key_file_set_integer(gkeyfile, "remmina_pref", "enc_mode", remmina_pref.enc_mode);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "audit", remmina_pref.audit);
@@ -1110,20 +1118,18 @@ void remmina_pref_set_value(const gchar *key, const gchar *value)
 	gsize length;
 
 	gkeyfile = g_key_file_new();
-	if (g_key_file_load_from_file(gkeyfile, remmina_pref_file, G_KEY_FILE_NONE, NULL))
-	{
+	if (g_key_file_load_from_file(gkeyfile, remmina_pref_file, G_KEY_FILE_NONE, NULL)) {
 		g_key_file_set_string(gkeyfile, "remmina_pref", key, value);
 		gchar *content = g_key_file_to_data(gkeyfile, &length, NULL);
 		if (g_file_set_contents(remmina_pref_file, content, length, NULL)) {
 			g_free(content);
 		} else {
-			REMMINA_WARNING ("Cannot save Remmina preferences");
-			REMMINA_WARNING ("Key was \"%s\", and value \"%s\"", key, value);
-
+			REMMINA_WARNING("Cannot save Remmina preferences");
+			REMMINA_WARNING("Key was \"%s\", and value \"%s\"", key, value);
 		}
 		g_key_file_free(gkeyfile);
 	} else {
-		REMMINA_WARNING ("Cannot load Remmina preferences file");
+		REMMINA_WARNING("Cannot load Remmina preferences file");
 	}
 }
 
